@@ -98,6 +98,10 @@ read_xml.character <- function(x, encoding = "", ..., as_html = FALSE,
     stop("Document is empty", call. = FALSE)
   }
 
+  if (length(x) > 1) {
+    stop("`x` must be a string of length 1", call. = FALSE)
+  }
+
   options <- parse_options(options, xml_parse_options())
   if (grepl("<|>", x)) {
     read_xml.raw(charToRaw(enc2utf8(x)), "UTF-8", ..., as_html = as_html, options = options)
@@ -120,8 +124,7 @@ read_xml.raw <- function(x, encoding = "", base_url = "", ...,
                          as_html = FALSE, options = "NOBLANKS") {
   options <- parse_options(options, xml_parse_options())
 
-  doc <- .Call(doc_parse_raw, x, encoding = encoding, base_url = base_url,
-    as_html = as_html, options = options)
+  doc <- .Call(doc_parse_raw, x, encoding, base_url, as_html, options)
   xml_document(doc)
 }
 
