@@ -104,6 +104,9 @@ extern "C" SEXP xpath_search(SEXP node_sxp, SEXP doc_sxp, SEXP xpath_sxp, SEXP n
 
   XPtrNode node(node_sxp);
   XPtrDoc doc(doc_sxp);
+  if (TYPEOF(xpath_sxp) != STRSXP) {
+    Rf_error("XPath must be a string, received %s", type2char(TYPEOF(xpath_sxp)));
+  }
   const char* xpath = CHAR(STRING_ELT(xpath_sxp, 0));
 
   double num_results = REAL(num_results_sxp)[0];
